@@ -1,7 +1,7 @@
 import os
 import unittest
 
-from transformers_keras.question_answering.callback import ExactMatchForQuestionAnswering, F1ForQuestionAnswering
+from transformers_keras.question_answering.callback import EMForQuestionAnswering, F1ForQuestionAnswering
 from transformers_keras.question_answering.models import BertForQuestionAnswering
 
 BERT_PATH = os.path.join(os.environ["CHINESE_BERT_PATH"], "chinese_roberta_wwm_ext_L-12_H-768_A-12")
@@ -12,7 +12,7 @@ class CallbackTest(unittest.TestCase):
     """Callback test"""
 
     def test_em_for_qa(self):
-        callback = ExactMatchForQuestionAnswering.from_jsonl_files(
+        callback = EMForQuestionAnswering.from_jsonl_files(
             input_files=[os.path.join(os.environ["SOGOUQA_PATH"], "sogouqa.test.jsonl")],
             vocab_file=VOCAB_PATH,
             padding="fixed",
