@@ -1,7 +1,7 @@
 import json
 import unittest
 
-from transformers_keras.token_classification.dataset import TokenClassificationDataset
+from transformers_keras.datapipe.tc_dataset import DatasetForTokenClassification
 
 
 class DatasetTest(unittest.TestCase):
@@ -17,7 +17,7 @@ class DatasetTest(unittest.TestCase):
 
     def test_dataset(self):
         print("====from_jsonl_files")
-        d = TokenClassificationDataset.from_jsonl_files(
+        d = DatasetForTokenClassification.from_jsonl_files(
             "testdata/token_classify.jsonl",
             vocab_file="testdata/vocab.bert.txt",
             label_vocab_file="testdata/labels.txt",
@@ -26,7 +26,7 @@ class DatasetTest(unittest.TestCase):
         print(next(iter(d)))
 
         print("====jsonl_to_examples")
-        examples = TokenClassificationDataset.jsonl_to_examples(
+        examples = DatasetForTokenClassification.jsonl_to_examples(
             "testdata/token_classify.jsonl",
             vocab_file="testdata/vocab.bert.txt",
             label_vocab_file="testdata/labels.txt",
@@ -35,14 +35,14 @@ class DatasetTest(unittest.TestCase):
             print(examples[i])
 
         print("====from_examples")
-        d = TokenClassificationDataset.from_examples(examples, batch_size=2)
+        d = DatasetForTokenClassification.from_examples(examples, batch_size=2)
         print(next(iter(d)))
 
         print("====examples_to_tfrecord")
-        TokenClassificationDataset.examples_to_tfrecord(examples, ["testdata/token_classify.tfrecord"])
+        DatasetForTokenClassification.examples_to_tfrecord(examples, ["testdata/token_classify.tfrecord"])
 
         print("====from_tfrecord_files")
-        d = TokenClassificationDataset.from_tfrecord_files("testdata/token_classify.tfrecord")
+        d = DatasetForTokenClassification.from_tfrecord_files("testdata/token_classify.tfrecord")
         print(next(iter(d)))
 
 
